.. ----------------------------------------------------------------------------
.. docs/source/installation.rst
..
.. Copyright (C) 2021 Maciej Wiatrzyk <maciej.wiatrzyk@gmail.com>
..
.. This file is part of PyDio library documentation
.. and is released under the terms of the MIT license:
.. http://opensource.org/licenses/mit-license.php.
..
.. See LICENSE.txt for details.
.. ----------------------------------------------------------------------------

Installation
============

You can install PyDio using one of following methods:

1) From PyPI (for stable releases)::

    $ pip install PyDio

2) From test PyPI (for stable and development releases)::

    $ pip install -i https://test.pypi.org/simple/ PyDio

3) Directly from source code repository (for all releases)::

    $ pip install git+https://gitlab.com/zef1r/PyDio.git@[branch-or-tag]
